==> pvfs-1.5.6.tgz: pvfs-1.5.6/utils/mgr-ping.c <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


#include "../config.h"
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <sockio.h>
#include <pvfs.h>

int parse_args(int argc, char **argv);
int usage(int argc, char **argv);

extern char *optarg;
extern int optind;

static char host[256] = "localhost";
static char fs[256] ="/";
static int port_nr = MGR_REQ_PORT;

int main(int argc, char **argv)
{
	int s, err;
	struct mreq req;
	struct mack ack;
	
	req.majik_nr   = MGR_MAJIK_NR;
	req.release_nr = PVFS_RELEASE_NR;
	req.type       = MGR_NOOP;
	req.dsize      = 0;

	s = new_sock();

	parse_args(argc, argv);
	if (optind < argc) {
		usage(argc, argv);
	}


	err = connect_sock(s, host, port_nr);
	if (err < 0) {
		fprintf(stderr, "mgr-ping: unable to connect to %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}

	err = bsend(s, &req, sizeof(req));
	if (err < 0) {
		fprintf(stderr, "mgr-ping: unable to send request to %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}

	err = brecv(s, &ack, sizeof(ack));
	if (err < 0) {
		fprintf(stderr, "mgr-ping: error receiving acknowledgement from %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}
	if (ack.majik_nr != MGR_MAJIK_NR) {
		fprintf(stderr, "mgr-ping: received garbage acknowledgement from %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}
	if (ack.release_nr != PVFS_RELEASE_NR) {
		fprintf(stderr, "mgr-ping: release number from %s:%d (%d.%d.%d) does not match release number built into this binary (%d.%d.%d).\n",
				  host,
				  port_nr,
				  ack.release_nr / 10000,
				  (ack.release_nr / 100) % 10,
				  ack.release_nr % 10,
				  PVFS_RELEASE_NR / 10000,
				  (PVFS_RELEASE_NR / 100) % 10,
				  PVFS_RELEASE_NR % 10);
		fprintf(stderr, "mgr-ping: an administrator needs to verify that all PVFS servers and clients are at the same release number.\n");
		fflush(stderr);
		goto oops;
	}
	printf("%s:%d is responding.\n", host, port_nr);
	exit(0);

oops:
	printf("%s:%d is down.\n", host, port_nr);
	exit(1);
}


int parse_args(int argc, char **argv)
{
	int c;

	while ((c = getopt(argc, argv, "h:p:")) != EOF) {
		switch(c) {
			case 'h':
				strncpy(host, optarg, 255);
				host[255] = 0;
				break;
			case 'p':
				port_nr = atoi(optarg);
				break;
			case 'f':
				strncpy(fs, optarg, 255);
				break;
			case '?':
				usage(argc, argv);
				break;
		}
	}
	return 1;
} /* end of PARSE_ARGS() */

int usage(int argc, char **argv)
{
	fprintf(stderr, "Usage: mgr-ping [-h host] [-p port] [-f metadata_dir]\n");
	exit(1);
} /* end of USAGE() */

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */

==> pvfs-1.5.7.tgz: pvfs-1.5.7/utils/mgr-ping.c <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


#include "../config.h"
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <sockio.h>
#include <pvfs.h>

int parse_args(int argc, char **argv);
int usage(int argc, char **argv);

extern char *optarg;
extern int optind;

static char host[256] = "localhost";
static char fs[256] ="/";
static int port_nr = MGR_REQ_PORT;

int main(int argc, char **argv)
{
	int s, err;
	struct mreq req;
	struct mack ack;
	
	req.majik_nr   = MGR_MAJIK_NR;
	req.release_nr = PVFS_RELEASE_NR;
	req.type       = MGR_NOOP;
	req.dsize      = 0;

	s = new_sock();

	parse_args(argc, argv);
	if (optind < argc) {
		usage(argc, argv);
	}


	err = connect_sock(s, host, port_nr);
	if (err < 0) {
		fprintf(stderr, "mgr-ping: unable to connect to %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}

	err = bsend(s, &req, sizeof(req));
	if (err < 0) {
		fprintf(stderr, "mgr-ping: unable to send request to %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}

	err = brecv(s, &ack, sizeof(ack));
	if (err < 0) {
		fprintf(stderr, "mgr-ping: error receiving acknowledgement from %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}
	if (ack.majik_nr != MGR_MAJIK_NR) {
		fprintf(stderr, "mgr-ping: received garbage acknowledgement from %s:%d.\n",
				  host, port_nr);
		fflush(stderr);
		goto oops;
	}
	if (ack.release_nr != PVFS_RELEASE_NR) {
		fprintf(stderr, "mgr-ping: release number from %s:%d (%d.%d.%d) does not match release number built into this binary (%d.%d.%d).\n",
				  host,
				  port_nr,
				  ack.release_nr / 10000,
				  (ack.release_nr / 100) % 10,
				  ack.release_nr % 10,
				  PVFS_RELEASE_NR / 10000,
				  (PVFS_RELEASE_NR / 100) % 10,
				  PVFS_RELEASE_NR % 10);
		fprintf(stderr, "mgr-ping: an administrator needs to verify that all PVFS servers and clients are at the same release number.\n");
		fflush(stderr);
		goto oops;
	}
	printf("%s:%d is responding.\n", host, port_nr);
	exit(0);

oops:
	printf("%s:%d is down.\n", host, port_nr);
	exit(1);
}


int parse_args(int argc, char **argv)
{
	int c;

	while ((c = getopt(argc, argv, "h:p:f:")) != EOF) {
		switch(c) {
			case 'h':
				strncpy(host, optarg, 255);
				host[255] = 0;
				break;
			case 'p':
				port_nr = atoi(optarg);
				break;
			case 'f':
				strncpy(fs, optarg, 255);
				break;
			case '?':
				usage(argc, argv);
				break;
		}
	}
	return 1;
} /* end of PARSE_ARGS() */

int usage(int argc, char **argv)
{
	fprintf(stderr, "Usage: mgr-ping [-h host] [-p port] [-f metadata_dir]\n");
	exit(1);
} /* end of USAGE() */

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */
